<%! from kaithem.src.util import url, memorableHash from kaithem.src import modules, modules_state def getDesc(m): try: d = modules_state.ActiveModules[m]['__metadata__']['description'] if d=='Module info here': return '' return d except: return "" %> <%include file="/pageheader.html"/>

# Modules

Library

${memorableHash(modules_state.moduleshash, 3, separator=' ').upper()}

%for i in sorted(ActiveModules.keys()):
%try: ${i}\ %if i in modules.external_module_locations: (${modules.external_module_locations[i]|h}) %endif \ %except Exception as e: <% print(e) %>
${e|h}
%endtry
${getDesc(i)|h}
%endfor
<%include file="/pagefooter.html"/>